import React from "react"
import styled from "styled-components"
import PropTypes from "prop-types"
import { fontFamily, colors, fontWeight, fontSize } from "buoy-theme"

const PillContainer = styled.div`
  font-family: ${fontFamily};
  font-weight: ${fontWeight.regular};
  ${fontSize("bodyMain")};
  display: flex;
  align-items: center;
  color: ${colors.neutralDarkest};
  background-color: ${colors.neutralLightest};
  border-radius: 4px;
  height: 28px;
  padding: 5px 16px;
  margin-right: 10px;
  margin-top: 5px;
  margin-bottom: 5px;
  white-space: nowrap;
  user-select: none;
`

export const Close = styled.div`
  display: flex;
  font-size: 20px;
  align-items: center;
  justify-content: center;
  font-weight: ${fontWeight.light};
  margin-left: 8px;
  margin-bottom: 2px;
  cursor: pointer;
`

const Pill = ({ text, onRemove, readonly }) => (
  <PillContainer>
    {text}
    {!readonly && <Close onClick={onRemove}>×</Close>}
  </PillContainer>
)

Pill.propTypes = {
  text: PropTypes.string.isRequired,
  onRemove: PropTypes.func,
  readonly: PropTypes.bool,
}

export { Pill as default }
